@@ -1,5 +1,4 @@
-# $Id: ProxyAuth.pm,v 1.1 2001/04/10 16:30:27 gbarr Exp $
-# Copyright (c) 2001 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 2001-2004 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -9,7 +8,7 @@ use vars qw(@ISA $VERSION);
 use Net::LDAP::Control;
 
 @ISA = qw(Net::LDAP::Control);
-$VERSION = do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r};
+$VERSION = "1.04";
 
 use Net::LDAP::ASN qw(proxyAuthValue);
 use strict;
@@ -90,7 +89,7 @@ of objects that represent the C<proxyauthorisationControl> as described by draft
 =head1 CONSTRUCTOR ARGUMENTS
 
 In addition to the constructor arguments described in
-L<Net::LDAP::Control|Net::LDAP::Control> the following are provided.
+L<Net::LDAP::Control> the following are provided.
 
 =over 4
 
@@ -102,33 +101,29 @@ The proxyDN that is required. This is the identity we are requesting operations
 
 =head1 METHODS
 
-As with L<Net::LDAP::Control|Net::LDAP::Control> each constructor argument
+As with L<Net::LDAP::Control> each constructor argument
 described above is also available as a method on the object which will
 return the current value for the attribute if called without an argument,
 and set a new value for the attribute if called with an argument.
 
 =head1 SEE ALSO
 
-L<Net::LDAP|Net::LDAP>,
-L<Net::LDAP::Control|Net::LDAP::Control>,
-http://info.internet.isi.edu/in-notes/rfc/files/rfc2696.txt
+L<Net::LDAP>,
+L<Net::LDAP::Control>,
 
 =head1 AUTHOR
 
-Olivier Dubois, Swift sa/nv based on Net::LDAP::Control::Page from Graham Barr <gbarr@pobox.com>
+Olivier Dubois, Swift sa/nv based on Net::LDAP::Control::Page from
+Graham Barr E<lt>gbarr@pobox.comE<gt>
 
-Please report any bugs, or post any suggestions, to the perl-ldap mailing list
-<perl-ldap-dev@lists.sourceforge.net>
+Please report any bugs, or post any suggestions, to the perl-ldap
+mailing list E<lt>perl-ldap@perl.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 Graham Barr. All rights reserved. This program is
+Copyright (c) 2001-2004 Graham Barr. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
-=for html <hr>
-
-I<$Id: ProxyAuth.pm,v 1.1 2001/04/10 16:30:27 gbarr Exp $>
-
 =cut
 
